@@ -27,4 +27,4 @@ class InterventionModel(Base):
         onupdate=lambda: datetime.utcnow(),
     )
 
-    __table_args__ = (UniqueConstraint("intervention_uid"))
+    __table_args__ = (UniqueConstraint("intervention_uid"),)
